from pathlib import Path

from bs4 import BeautifulSoup
from django.core.management.base import BaseCommand, CommandError

from ...models import Page


class Command(BaseCommand):
    help = "add missing cms files to database"

    def add_arguments(self, parser):
        parser.add_argument(
            "-f", "--force", action="store_true", help="Always overwrite content"
        )
        parser.add_argument("pages", help="Specify which pages to import", nargs="*")

    def handle(self, *args, **options):
        content_path = Path(__file__).resolve().parent.parent.parent / "default_content"
        for file in content_path.iterdir():
            if (pages := options["pages"]) and file.stem not in pages:
                continue

            slug = file.stem
            p, created = Page.objects.get_or_create(url=slug)
            if (not created) and (not options["force"]):
                continue

            soup = BeautifulSoup(file.read_text(), "html.parser")

            if soup.title:
                p.title = soup.title.string
                soup.title.decompose()
            else:
                p.title = slug.title()

            if visible := soup.find("meta", attrs={"name": "visible"}):
                p.visible = "content" not in visible.attrs or visible.attrs[
                    "content"
                ].lower() in ("1", "true", "yes")
                visible.decompose()

            p.content = str(soup).strip()
            p.save()
            print(f'created new page "{p.title}" for slug {slug}')
